@@ -12,7 +12,8 @@ from skgstat_uncertainty.processor import sampling
 
 ACT = {
     'upload': 'Uplaod new dataset',
-    'sample': 'Sample an existing dataset'
+    'sample': 'Sample an existing dataset',
+    'list': 'List existing dataset'
 }
 
 
@@ -121,6 +122,35 @@ def sample_dense_data(dataset: DataUpload, api: API):
     st.stop()
 
 
+def list_datasets(api: API, container=st):
+    # select a dataset
+    all_names = api.get_upload_names()
+    data_id = container.selectbox('DATASET', options=list(all_names.keys()), format_func=lambda k: all_names.get(k))
+    dataset = api.get_upload_data(id=data_id)
+
+    # preview data
+    container.title(f"{dataset.data_type.upper()} dataset")
+
+    if 'origin' in dataset.data:
+        container.markdown(dataset.data['origin'])
+
+    # create a preview plot
+    components.dataset_plot(dataset, disable_download=False)
+
+    # some basic stats
+    stats = [
+        {'Stat': 'Estimated experimental variograms', 'Value': len(dataset.variograms)},
+        {'Stat': 'Total number of fitted models', 'Value': np.sum([[len(cv.models) for cv in v.conf_intervals] for v in dataset.variograms])},
+    ]
+
+    # check if there is a parent field
+    if 'field_id' in dataset.data:
+        stats.append({'Stat': 'Parent field id', 'Value': dataset.data['field_id']})
+
+    container.markdown('## Related data')
+    container.table(stats)
+
+
 def main_app(api: API):
     st.title('Data Upload manager')
     st.markdown("Use this chapter to upload new datasets and create new samples.")
@@ -135,16 +165,15 @@ def main_app(api: API):
 
         # add auxiliary upload
         components.upload_auxiliary_data(dataset=dataset, api=api)
+        st.markdown('### Preview')
+        components.dataset_plot(dataset=dataset)
+        
+            # check if this dataset has origin information
+        if 'origin' in dataset.data:
+            origin = dataset.data['origin']
 
-        # plot the uploaded data
-        fig = go.Figure(go.Heatmap(z=dataset.data['field']))
-        fig.update_layout(
-            height=750,
-            yaxis=dict(scaleanchor='x'), 
-            plot_bgcolor='rgba(0,0,0,0)'
-        )
-        st.plotly_chart(fig, use_container_width=True)
-
+            oexp = st.expander('DATASET INFO', expanded=True)
+            oexp.markdown(f'## Origin information\n{origin}')
 
     elif action == 'sample':
         # create the data select
@@ -152,10 +181,9 @@ def main_app(api: API):
 
         # dev only 
         sample_dense_data(dataset=dataset, api=api)
-
-    st.success('Finished!')
-
-
+    
+    elif action == 'list':
+        list_datasets(api=api)
 
 
 if __name__=='__main__':
