@@ -1,4 +1,5 @@
 from typing import Tuple, List
+import warnings
 
 import streamlit as st
 import numpy as np
@@ -56,12 +57,22 @@ def apply_model(vario: VarioParams, interval: VarioConfInterval, figure: go.Figu
     # get the variogram and bounds
     variogram = vario.variogram
     bounds = interval.spec['interval']
-    max_bound = float(np.nanmax([b[1] for b in bounds]))
-    max_bin = float(np.max(variogram.bins))
+    max_bound = float(np.nanmax([b[1] for b in bounds]).round(2))
+    max_bin = float(np.nanmax(variogram.bins).round(2))
 
     model = st.sidebar.selectbox('Theoretical model', options=list(MODELS.keys()), format_func=lambda k: MODELS.get(k))
-    nugget, sill = st.sidebar.slider('Nugget and sill', min_value=0.0, max_value=2 * max_bound, value=[0.0, 0.98 * max_bound])
-    _range = st.sidebar.slider('Effective Range', min_value=0.0, max_value=float(np.max(variogram.bins)), value=max_bin)
+    nugget, sill = st.sidebar.slider(
+        'Nugget and sill',
+        min_value=0.0,
+        max_value=float(np.round(1.3 * max_bound, 2)),
+        value=[0.0, float(np.round(0.98 * max_bound, 2))]
+    )
+    _range = st.sidebar.slider(
+        'Effective Range',
+        min_value=0.0,
+        max_value=max_bin,
+        value=float(np.round(0.5*max_bin, 2))
+    )
     if model == 'stable':
         _s = st.sidebar.slider('Shape Parameter', min_value=0.05, max_value=2.0, value=0.5)
     elif model == 'matern':
@@ -144,21 +155,36 @@ def evaluate_fit(vario: VarioParams, interval: List[Tuple[float, float]], params
 
     # check if the given model was already used
     if len(other_models) > 0:
-        # check if there are any
-        mod_rmse_ = np.nanmean([m.parameters['measures'].get('RMSE', np.nan) for m in other_models if m.parameters['model_params']['model'] == params['model']])
-        mod_cv_ = np.nanmean([m.parameters['measures'].get('cross-validation', np.nan) for m in other_models if m.parameters['model_params']['model'] == params['model']])
-        mod_rank = stats.rankdata([cv, *[m.parameters['measures'].get('cross-validation', np.nan) for m in other_models if m.parameters['model_params']['model'] == params['model']]], method='min')[0]
-        
-        # fancy
-        mod_rank = '1st' if mod_rank == 1 else mod_rank
-        mod_rank = '2nd' if mod_rank == 2 else mod_rank
-        mod_rank = '3rd' if mod_rank == 3 else mod_rank
-        mod_rank = f'{mod_rank}th' if not isinstance(mod_rank, str) and mod_rank > 3 else mod_rank
+        # get the warnings
+        with warnings.catch_warnings():
+            warnings.filterwarnings('error')
 
-        # calculate deviation
-        mod_rmse = (rmse - mod_rmse_).round(1)
-        mod_cv = (cv - mod_cv_).round(1)
-        mod_rank_dev = f"of {len([1 for m in other_models if m.parameters['model_params']['model'] == params['model']]) + 1} {params['model']} models"
+            # RMSE
+            try:
+                mod_rmse_ = np.nanmean([m.parameters['measures'].get('RMSE', np.nan) for m in other_models if m.parameters['model_params']['model'] == params['model']])
+                mod_rmse = (rmse - mod_rmse_).round(1)
+            except Warning:
+                mod_rmse = None
+            
+            # CROSS-VALIDATION
+            try:
+                mod_cv_ = np.nanmean([m.parameters['measures'].get('cross-validation', np.nan) for m in other_models if m.parameters['model_params']['model'] == params['model']])
+                mod_cv = (cv - mod_cv_).round(1)
+            except Warning:
+                mod_cv = None
+        
+            # CV RANK
+            try:
+                mod_rank = stats.rankdata([cv, *[m.parameters['measures'].get('cross-validation', np.nan) for m in other_models if m.parameters['model_params']['model'] == params['model']]], method='min')[0]
+        
+                # fancy
+                mod_rank = '1st' if mod_rank == 1 else mod_rank
+                mod_rank = '2nd' if mod_rank == 2 else mod_rank
+                mod_rank = '3rd' if mod_rank == 3 else mod_rank
+                mod_rank = f'{mod_rank}th' if not isinstance(mod_rank, str) and mod_rank > 3 else mod_rank
+                mod_rank_dev = f"of {len([1 for m in other_models if m.parameters['model_params']['model'] == params['model']]) + 1} {params['model']} models"
+            except Warning:
+                mod_rank_dev = None    
         
     else:
         mod_rmse = None
