@@ -1,3 +1,3 @@
 from .data_selects import upload_handler, upload_auxiliary_data, data_selector
-from .plotting import single_result_plot
+from .plotting import single_result_plot, dataset_plot
 from .tables import model_table
\ No newline at end of file
