@@ -3,7 +3,7 @@ from typing import List
 from skgstat_uncertainty.models import VarioModel
 
 
-def variomodel_to_dict(models: List[VarioModel]) -> List[dict]:
+def variomodel_to_dict(models: List[VarioModel], add_measures = False) -> List[dict]:
     # build up the data for the table
     data = list()
 
@@ -13,6 +13,8 @@ def variomodel_to_dict(models: List[VarioModel]) -> List[dict]:
         # get the parameters
         d.update(model.parameters.get('model_params', {}))
 
+        if add_measures:
+            d.update(model.parameters.get('measures', {}))
         # append
         data.append(d)
 
